L2Cost
=========================================

.. currentmodule:: skchange.costs

.. autofunction:: L2Cost

.. include:: skchange.costs.L2Cost.examples

.. raw:: html

    <div class="clearer"></div>